DataLad |---| data management and publication multitool: Documentation
**********************************************************************

.. toctree::
   :maxdepth: 1

   gettingstarted
   changelog
   acknowledgements
   publications

Concepts and technologies
=========================

.. toctree::
   :maxdepth: 2

   background
   related
   basics
   usecases/index
   metadata
   customization
   glossary

Commands and API
================

.. toctree::
   :maxdepth: 2

   cmdline
   modref
   config

Extension packages
==================

DataLad can be customized and additional functionality can be integrated via
extensions.  Each extension provides its own documentation:

- `Crawling web resources and automated data distributions <http://docs.datalad.org/projects/crawler>`_
- `Neuroimaging data and workflows <http://docs.datalad.org/projects/neuroimaging>`_
- `Containerized computational environments <http://docs.datalad.org/projects/container>`_
- `Alternative set of basic commands with improved cross-platform support <http://docs.datalad.org/projects/revolution>`_

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. |---| unicode:: U+02014 .. em dash
